#!/bin/sh
#
# initialization script for Symantec Scan Engine
#
# Copyright 1998-2006, Symantec Corporation.  All rights reserved.
# 
# All of the documentation and software included as a part of the 
# Scan Engine software package is subject to the License Agreement 
# provided with the package.  Usage or copying of the software or 
# documentation except as permitted by the License Agreement is unlawful.
# 
# Symantec and Symantec Scan Engine are trademarks or registered
# trademarks of Symantec Corporation in the United States and other countries.
# 
# THIS SOFTWARE IS PROVIDED BY SYMANTEC CORPORATION AND CONTRIBUTORS ``AS IS'' 
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL SYMANTEC OR CONTRIBUTORS BE LIABLE FOR
# ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
# SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.
#


PATH=/usr/bin:/bin:/bin
InstallDir=/opt/SYMCScan
Program=$InstallDir/bin/symcscan
ConfigFile=$InstallDir/bin
Product="SYMCScan"
#...jre/lib/i386
JavaJRELib=

start() {
    if [ ! -f $Program ]; then
        echo "Symantec Scan Engine executable ($Program) is missing. Please try reinstalling Symantec Scan Engine." 
	exit 1
    fi
    
    pids=`ps -aef | grep "$Program" | grep -v grep | grep -v '\.sh' | awk '{print $2}'`

    if [ x"$pids" != x ]; then
        echo "Symantec Scan Engine is already running..."
        exit 0
    fi

    echo "Starting Symantec Scan Engine, please wait..."
    rel=`rpm -qa | grep redhat-release | awk -F - '{print $3}'`
    if [ "x$rel" = "x9" ]; then
 	LD_ASSUME_KERNEL=2.4.1
	export LD_ASSUME_KERNEL
    fi
    LD_LIBRARY_PATH=$InstallDir/bin:$JavaJRELib:$JavaJRELib/client:${LD_LIBRARY_PATH}
    export LD_LIBRARY_PATH
    export PATH
    umask 002
    $Program -config:$ConfigFile -daemon
}

version() {
    if [ ! -f $Program ]; then
        echo "Symantec Scan Engine executable ($Program) is missing. Please try reinstalling Symantec Scan Engine."
	exit 1
    fi

    LD_LIBRARY_PATH=$InstallDir/bin:$JavaJRELib:$JavaJRELib/client:${LD_LIBRARY_PATH}
    export LD_LIBRARY_PATH
    $Program -config:$ConfigFile -version
}

stop() {

	pids=`ps -aef | grep "$Program" | grep -v grep | grep -v '\.sh' | awk '{print $2}'`

	if [ x"$pids" != x ]; then
		echo "Shutting down Symantec Scan Engine, please wait..." 

		count=50
		while [ x"$pids" != x -a $count -gt 0 ]; do
		    sleep 1
		    count=`expr $count - 1`
		    kill -15 $pids >/dev/null 2>&1
		    pids=`ps -aef | grep "$Program" | grep -v grep | grep -v '\.sh' | awk '{print $2}'`
		done
		if [ x"$pids" != x ]; then
		    echo "Graceful approach failed, shutting down Symantec Scan Engine abruptly."
		    kill -9 $pids >/dev/null 2>&1
		fi
	fi

	jlupid=`ps -aef | grep 'com.symantec.liveupdate.LiveUpdate' | grep -v 'grep' | awk  '{print $2;}'`

	for i in $jlupid; do
	if [ x"$jlupid" != x ]; then
		kill -9 $i  > /dev/null 2> /dev/null
	fi
	done
}

case "$1" in
  start)
	start
	;;

  stop)
	stop
	;;

  restart|reload)
	stop
	start
	;;
  version)
	version
	;;
  *)
	echo "usage: $0 {start|stop|restart|reload|version}"
	;;
esac
